==> haskell-data-serializer-0.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-9WFccAilONr3Wb9VwWeLkx
key: data-serializer-0.3-9WFccAilONr3Wb9VwWeLkx
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Serializer Data.Deserializer
abi: ca2520a5d457cd7224861f9ead4d26c4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-serializer-0.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-9WFccAilONr3Wb9VwWeLkx
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    data-endian-0.1.1-8uxPbJpGjmuKDaF1nxHF2h
    parsers-0.12.4-9TuAHJrDdtVLctSD9PovNx
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-7cp0KvvTPxkEa4OnQUA9yo
key: data-serializer-0.3-7cp0KvvTPxkEa4OnQUA9yo
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Serializer Data.Deserializer
abi: 93c8a3075c5f7d6901b01324eec98937
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-serializer-0.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-7cp0KvvTPxkEa4OnQUA9yo
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    data-endian-0.1.1-8uxPbJpGjmuKDaF1nxHF2h
    parsers-0.12.4-EBlSUG1fQQN7VVgX5vOcmk
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
